@@ -14,27 +14,11 @@
 
 import socket
 
-import requests
-from starlette.concurrency import run_in_threadpool
-
 from platformio import util
 from platformio.compat import IS_WINDOWS
 from platformio.proc import where_is_program
 
 
-class AsyncSession(requests.Session):
-    async def request(  # pylint: disable=signature-differs,invalid-overridden-method
-        self, *args, **kwargs
-    ):
-        func = super().request
-        return await run_in_threadpool(func, *args, **kwargs)
-
-
-@util.memoized(expire="60s")
-def requests_session():
-    return AsyncSession()
-
-
 @util.memoized(expire="60s")
 def get_core_fullpath():
     return where_is_program("platformio" + (".exe" if IS_WINDOWS else ""))
