@@ -168,7 +168,7 @@ class ProjectConfigBase:
                 yield (section, option)
             if self._parser.has_option(section, "extends"):
                 extends_queue.extend(
-                    self.parse_multi_values(self._parser.get(section, "extends"))[::-1]
+                    self.parse_multi_values(self._parser.get(section, "extends"))
                 )
 
     def options(self, section=None, env=None):
@@ -319,7 +319,13 @@ class ProjectConfigBase:
         if section == "this":
             section = parent_section
             if option == "__env__":
-                assert parent_section.startswith("env:")
+                if not parent_section.startswith("env:"):
+                    raise exception.ProjectOptionValueError(
+                        f"`${{this.__env__}}` is called from the `{parent_section}` "
+                        "section that is not valid PlatformIO environment, see",
+                        option,
+                        section,
+                    )
                 return parent_section[4:]
         # handle nested calls
         try:
