@@ -133,6 +133,11 @@ ProjectOptions = OrderedDict(
             #
             # [platformio]
             #
+            ConfigPlatformioOption(
+                group="generic",
+                name="name",
+                description="A project name",
+            ),
             ConfigPlatformioOption(
                 group="generic",
                 name="description",
