@@ -117,6 +117,9 @@ class TestRunnerBase:
     def stage_building(self):
         if self.options.without_building:
             return None
+        # run "building" once at the "uploading" stage for the embedded target
+        if not self.options.without_uploading and self.platform.is_embedded():
+            return None
         click.secho("Building...", bold=True)
         targets = ["__test"]
         if not self.options.without_debugging:
@@ -125,16 +128,19 @@ class TestRunnerBase:
             targets.append("checkprogsize")
         try:
             return self.run_project_targets(targets)
-        except ReturnErrorCode:
+        except ReturnErrorCode as exc:
             raise UnitTestSuiteError(
                 "Building stage has failed, see errors above. "
                 "Use `pio test -vvv` option to enable verbose output."
-            )
+            ) from exc
 
     def stage_uploading(self):
-        if self.options.without_uploading or not self.platform.is_embedded():
+        is_embedded = self.platform.is_embedded()
+        if self.options.without_uploading or not is_embedded:
             return None
-        click.secho("Uploading...", bold=True)
+        click.secho(
+            "Building & Uploading..." if is_embedded else "Uploading...", bold=True
+        )
         targets = ["upload"]
         if self.options.without_building:
             targets.append("nobuild")
@@ -144,11 +150,11 @@ class TestRunnerBase:
             targets.append("__debug")
         try:
             return self.run_project_targets(targets)
-        except ReturnErrorCode:
+        except ReturnErrorCode as exc:
             raise UnitTestSuiteError(
                 "Uploading stage has failed, see errors above. "
                 "Use `pio test -vvv` option to enable verbose output."
-            )
+            ) from exc
 
     def stage_testing(self):
         if self.options.without_testing:
@@ -188,7 +194,7 @@ class TestRunnerBase:
             target=targets,
         )
 
-    def configure_build_env(self, env):  # pylint: disable=no-self-use
+    def configure_build_env(self, env):
         """
         Configure SCons build environment
         Called in "builder/tools/piotest" tool
@@ -206,5 +212,5 @@ class TestRunnerBase:
             self._testing_output_buffer = self._testing_output_buffer[nl_pos + 1 :]
             self.on_testing_line_output(line)
 
-    def on_testing_line_output(self, line):  # pylint: disable=no-self-use
+    def on_testing_line_output(self, line):
         click.echo(line, nl=False)
